
% natl_heatflux2.m
%
% Calculate variations in the net northward heat flux in
% the North Atlantic Ocean from the UWM/COADS
% mean net heat flux, as in Budyko (1963).
% 

clear all;

years=[45:89];
latflux=48;

Fflux=NaN*ones(size(years));

for yr=1:length(years);

% load COADS fields
clear landmask;
[lon_coads,lat_coads,lonvec,latvec,sss,index, ...
         sst,netheat,eminusp,taux,tauy]=loadcoadsyear(years(yr));

% discard values outside N. Atl.
disp('Isolating North Atlantic.');
load atlcoords x y
q=~isinpoly(lonvec,latvec,x,y);
truncatecoads
clear sss sst eminusp taux tauy x y q n;

% calculate net heat flux
nummonths=size(netheat,1);
q=NaN*ones(length(lat_coads),length(lon_coads));
Q=NaN*ones(length(lat_coads),length(lon_coads),nummonths);
for mn=1:nummonths;
  q(index)=netheat(mn,:);
  Q(:,:,mn)=q;
end;
clear q;
Q=mean(Q,3);
% convert from W/m^2 to W
Area=sw_area(lon_coads,lat_coads);
Q=Q.*Area;

% now calculate oceanic heat flux as a function of latitude:
%   all heat loss north of latitude phi must be imported
%   by the ocean.
F=NaN*ones(size(lat_coads));
for i=1:length(lat_coads);
  q=find(lat_coads>lat_coads(i));
  F(i)=-nansum(nansum(Q(q,:)));
end;

dlat=(lat_coads-latflux).^2;
q=find(dlat==min(dlat));

Fflux(yr)=mean(F(q));

end;	% loop over years

% plot results
clf;

% first plot NAO index;
years=years+1900;
naoind;
year2=(min(year):.01:max(year))';
nao2=interp1(year,nao,year2);
nao=nao2;year=year2;
q=find(year>=min(years) & year<=max(years));
nao=nao(q);year=year(q);
% normalize index to be inside +-1
nao=nao/max(abs(nao));
plot(year,nao,'k');
hold on;
nao2=nao;
q=find(nao2<0);
nao2(q)=0;
patch([year;flipud(year)], ...
  [nao2;zeros(size(nao2))],'r','edgecolor','none');
nao2=nao;
q=find(nao2>0);
nao2(q)=0;
patch([year;flipud(year)], ...
  [nao2;zeros(size(nao2))],'b','edgecolor','none');
plot(year,nao,'k','linewidth',1);

% now superimpose heat flux
plot(years,Fflux/1e15,'k');
plot(years,Fflux/1e15,'.k','markersize',20);
ttl='Inferred oceanic heat flux (PW) at ';
ttl=[ttl,num2str(latflux),'^\circN'];
ttl=[ttl,' from UWM/COADS net heat flux'];
title(ttl);
grid on;
hold off;
